function newLabExperiment(dz)
% newLabExperiment  Design flow through pipes driven by a head tank

if nargin<1, dz = -3;  end

L = 20;                    %  pipe length (m)
D = 0.0254/2;              %  true pipe diameter (m)
A = 0.25*pi*D^2;           %  cross sectional area (m^2)
e = 0.26e-3;               %  roughness for cast iron
% e = 0;
KL = [0.5;  1];            %  minor loss for entrance and exit
Ah = A(1)*ones(size(A));   %  Areas of pipe associated with minor loss
                           %     coefficients are same as pipe area
rho = 999.7;               %  density of water (kg/m^3) at 10 degrees C
mu = 1.307e-3;             %  dynamic viscosity (kg/m/s) at 10 degrees C
nu = mu/rho;               %  kinematic viscosity (m^2/s)
pc = [];                   %  no pump
Q0 = [5e-9 1];             %  initial guess at flow rate

[Q,~,~] = pipeFlowSolve(Q0,L,A,D,e,KL,[A; A],nu,dz,pc);

GPM = Q*60/3.7854e-3;

fprintf('\nFlow rate, Q = %12.3e (m^3/s) = %12.3e (GPM)\n',Q,GPM);

end